This module contains macros to be used in the kudu crates.
Feature flags
detailed-error: activate this to enable thewith_locationmacro. If not enabled, thewith_locationmacro will be a no-op.
This module contains macros to be used in the kudu crates.
detailed-error: activate this to enable the with_location macro. If
not enabled, the with_location macro will be a no-op.